### R code from vignette source 'apcluster.Rnw'

###################################################
### code chunk number 1: Init
###################################################
options(width=75)
set.seed(0)
library(apcluster)
apclusterVersion <- packageDescription("apcluster")$Version
apclusterDateRaw <- packageDescription("apcluster")$Date
apclusterDateYear <- as.numeric(substr(apclusterDateRaw, 1, 4))
apclusterDateMonth <- as.numeric(substr(apclusterDateRaw, 6, 7))
apclusterDateDay <- as.numeric(substr(apclusterDateRaw, 9, 10))
apclusterDate <- paste(month.name[apclusterDateMonth], " ",
                     apclusterDateDay, ", ",
                     apclusterDateYear, sep="")


###################################################
### code chunk number 2: InstallAPCluster (eval = FALSE)
###################################################
## install.packages("apcluster")


###################################################
### code chunk number 3: LoadAPCluster (eval = FALSE)
###################################################
## library(apcluster)


###################################################
### code chunk number 4: OpenVignette (eval = FALSE)
###################################################
## vignette("apcluster")


###################################################
### code chunk number 5: ShowHelp (eval = FALSE)
###################################################
## help(apcluster)


###################################################
### code chunk number 6: CreateDataSet1
###################################################
cl1 <- cbind(rnorm(30, 0.3, 0.05), rnorm(30, 0.7, 0.04))
cl2 <- cbind(rnorm(30, 0.7, 0.04), rnorm(30, 0.4, .05))
x1 <- rbind(cl1, cl2)
plot(x1, xlab="", ylab="", pch=19, cex=0.8)


###################################################
### code chunk number 7: NegDistMatDataSet1
###################################################
s1 <- negDistMat(x1, r=2)


###################################################
### code chunk number 8: APClusterDataSet1
###################################################
apres1a <- apcluster(s1)


###################################################
### code chunk number 9: ShowHelpAPResult (eval = FALSE)
###################################################
## help(APResult)


###################################################
### code chunk number 10: ShowResultAPClusterDataSet1
###################################################
apres1a


###################################################
### code chunk number 11: PlotResultAPClusterDataSet1
###################################################
plot(apres1a, x1)


###################################################
### code chunk number 12: HeatmapResultAPClusterDataSet1
###################################################
plot(apres1a, s1)


###################################################
### code chunk number 13: APClusterDataSet1Details
###################################################
apres1b <- apcluster(s1, details=TRUE)


###################################################
### code chunk number 14: PlotAPClusterDataSet1Details
###################################################
plot(apres1b)


###################################################
### code chunk number 15: APClusterDataSet1convits15
###################################################
apres1c <- apcluster(s1, convits=15, details=TRUE)
apres1c


###################################################
### code chunk number 16: CreateDataSet2
###################################################
cl3 <- cbind(rnorm(20, 0.50, 0.03), rnorm(20, 0.72, 0.03))
cl4 <- cbind(rnorm(25, 0.50, 0.03), rnorm(25, 0.42, 0.04))
x2 <- rbind(x1, cl3, cl4)
s2 <- negDistMat(x2, r=2)
plot(x2, xlab="", ylab="", pch=19, cex=0.8)


###################################################
### code chunk number 17: APClusterDataSet2
###################################################
apres2a <- apcluster(s2)
plot(apres2a, x2)


###################################################
### code chunk number 18: APClusterDataSet2q0
###################################################
apres2b <- apcluster(s2, q=0)
plot(apres2b, x2)


###################################################
### code chunk number 19: PlotAPClusterDataSet2q08
###################################################
apres2c <- apcluster(s2, q=0.8)
plot(apres2c, x2)


###################################################
### code chunk number 20: APClusterDataSet2q08showp
###################################################
apres2c@p


###################################################
### code chunk number 21: HeatmapResultAPClusterDataSet2q08
###################################################
plot(apres2c, s2)


###################################################
### code chunk number 22: PreferenceRangeDataSet2
###################################################
preferenceRange(s2)


###################################################
### code chunk number 23: APClusterKDataSet2
###################################################
apres2d <- apclusterK(s2, K=2, verbose=TRUE)
plot(apres2d, x2)


###################################################
### code chunk number 24: AggExClusterDataSet1
###################################################
aggres1a <- aggExCluster(s1)
aggres1a


###################################################
### code chunk number 25: DendrogramAggExClusterDataSet1
###################################################
plot(aggres1a)


###################################################
### code chunk number 26: HeatmapAggExClusterDataSet1
###################################################
plot(aggres1a, s1)


###################################################
### code chunk number 27: ExtractAggExClustersDataSet1
###################################################
cl1a <- cutree(aggres1a, k=2)
cl1a
plot(cl1a, x1)


###################################################
### code chunk number 28: AggExClusterAPDataSet2q08
###################################################
aggres2a <- aggExCluster(s2, apres2c)
aggres2a


###################################################
### code chunk number 29: DendrogramAggExAPDataSet2
###################################################
plot(aggres2a)


###################################################
### code chunk number 30: HeatmapAggExAPDataSet2
###################################################
plot(aggres2a, s2)


###################################################
### code chunk number 31: PlotAggExAPDataSet2k25
###################################################
par(mfrow=c(2,2))
for (k in 5:2)
    plot(aggres2a, x2, k=k, main=paste(k, "clusters"))


###################################################
### code chunk number 32: LoadCh22Promoters
###################################################
data(ch22Promoters)
names(ch22Promoters)[1:5]
substr(ch22Promoters[1:5], 951, 1000)


###################################################
### code chunk number 33: SimCh22Promoters
###################################################
library(kernlab)
promSim <- kernelMatrix(stringdot(length=6, type="spectrum"), ch22Promoters)
rownames(promSim) <- names(ch22Promoters)
colnames(promSim) <- names(ch22Promoters)


###################################################
### code chunk number 34: APCh22Promoters
###################################################
promAP <- apcluster(promSim, q=0)
promAP


###################################################
### code chunk number 35: HeatMapAPCh22Promoters
###################################################
plot(promAP, promSim)


###################################################
### code chunk number 36: aggExCh22Promoters
###################################################
promAgg <- aggExCluster(promSim, promAP)


###################################################
### code chunk number 37: DendrogramAPCh22Promoters
###################################################
plot(promAgg)


###################################################
### code chunk number 38: ExtractAggCh22Promoters
###################################################
prom5 <- cutree(promAgg, k=5)
prom5


###################################################
### code chunk number 39: HeatMap5Ch22Promoters
###################################################
plot(prom5, promSim)


###################################################
### code chunk number 40: NegDistMatDataSet2 (eval = FALSE)
###################################################
## s2 <- negDistMat(x2, r=2)


###################################################
### code chunk number 41: CreateToyData
###################################################
ex <- matrix(c(0,0,1,0,0.5,0.5,0,1,1,1),5,2,byrow=TRUE)
ex


###################################################
### code chunk number 42: NegEuclDistMatToyData
###################################################
negDistMat(ex)


###################################################
### code chunk number 43: NegSqEuclDistMatToyData
###################################################
negDistMat(ex, r=2)


###################################################
### code chunk number 44: NegMaxDistToyData
###################################################
negDistMat(ex, method="maximum")


###################################################
### code chunk number 45: NegManhattanDistToyData
###################################################
negDistMat(ex,method="manhattan")


###################################################
### code chunk number 46: NegCanberraDistToyData
###################################################
negDistMat(ex,method="canberra")


###################################################
### code chunk number 47: NegMinkowskiDistToyData
###################################################
negDistMat(ex, method="minkowski", p=3)


###################################################
### code chunk number 48: RBFKernelToyData
###################################################
expSimMat(ex)


###################################################
### code chunk number 49: LaplaceKernelToyData
###################################################
expSimMat(ex, r=1)


###################################################
### code chunk number 50: TruncDistToyData
###################################################
linSimMat(ex, w=1.2)


###################################################
### code chunk number 51: LinKernelToyData
###################################################
linKernel(ex[2:5,])


###################################################
### code chunk number 52: NormLinKernelToyData
###################################################
linKernel(ex[2:5,], normalize=TRUE)


###################################################
### code chunk number 53: CreateLabeledToyData
###################################################
x3 <- c(1, 2, 3, 7, 8, 9)
names(x3) <- c("a", "b", "c", "d", "e", "f")
s3 <- negDistMat(x3, r=2)


###################################################
### code chunk number 54: ShowToyDataLabels
###################################################
s3
colnames(s3)


###################################################
### code chunk number 55: ClusterLabeledToyData
###################################################
apres3a <-apcluster(s3)
apres3a
apres3a@exemplars
apres3a@clusters


###################################################
### code chunk number 56: ExtractLabelsFromClusterToyData
###################################################
apres3a@exemplars
labels(apres3a, type="names")
labels(apres3a, type="exemplars")
labels(apres3a, type="enum")


###################################################
### code chunk number 57: GetBibTeX (eval = FALSE)
###################################################
## toBibtex(citation("apcluster"))


